@@ -1,15 +1,13 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2010 Kare Sars <kare dot sars at iki dot fi>
  * SPDX-FileCopyrightText: 2009 Matthias Nagl <matthias at nagl dot info>
  * SPDX-FileCopyrightText: 2009 Grzegorz Kurtyka <grzegorz dot kurtyka at gmail dot com>
  * SPDX-FileCopyrightText: 2007-2008 Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
  * SPDX-FileCopyrightText: 2021 Alexander Stippich <a.stippich@gmx.net>
- * 
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
- * ============================================================ */
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
 
 #include "ksanewidget.h"
 #include "ksanewidget_p.h"
@@ -24,9 +22,9 @@
 #include <QIcon>
 #include <QShortcut>
 
-#include <kpassworddialog.h>
+#include <KPasswordDialog>
 #ifdef HAVE_KF5WALLET
-#include <kwallet.h>
+#include <KWallet>
 #endif
 
 #include <KLocalizedString>
@@ -40,17 +38,16 @@ namespace KSaneIface
 KSaneWidget::KSaneWidget(QWidget *parent)
     : QWidget(parent), d(new KSaneWidgetPrivate(this))
 {
-    d->m_ksaneCoreInterface = new KSaneCore();
-    
-    connect(d->m_ksaneCoreInterface, &KSaneCore::scannedImageReady, d, &KSaneWidgetPrivate::imageReady);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::scanFinished, d, &KSaneWidgetPrivate::scanDone);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::userMessage, d, &KSaneWidgetPrivate::alertUser);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::scanProgress, d, &KSaneWidgetPrivate::updateProgress);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::batchModeCountDown, d, &KSaneWidgetPrivate::updateCountDown);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::availableDevices, d, &KSaneWidgetPrivate::signalDevListUpdate);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::buttonPressed, this, &KSaneWidget::buttonPressed);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::openedDeviceInfoUpdated, this, &KSaneWidget::openedDeviceInfoUpdated);
-    
+    d->m_ksaneCoreInterface = new KSaneCore::Interface();
+
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::scannedImageReady, d, &KSaneWidgetPrivate::imageReady);
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::scanFinished, d, &KSaneWidgetPrivate::scanDone);
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::userMessage, d, &KSaneWidgetPrivate::alertUser);
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::scanProgress, d, &KSaneWidgetPrivate::updateProgress);
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::batchModeCountDown, d, &KSaneWidgetPrivate::updateCountDown);
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::availableDevices, d, &KSaneWidgetPrivate::signalDevListUpdate);
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::buttonPressed, this, &KSaneWidget::buttonPressed);
+
     // Create the static UI
     // create the preview
     d->m_previewViewer = new KSaneViewer(&(d->m_previewImg), this);
@@ -72,7 +69,7 @@ KSaneWidget::KSaneWidget(QWidget *parent)
     d->m_cancelBtn = new QPushButton;
     d->m_cancelBtn->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
     d->m_cancelBtn->setToolTip(i18n("Cancel current scan operation"));
-    connect(d->m_cancelBtn, &QPushButton::clicked, this, &KSaneWidget::scanCancel);
+    connect(d->m_cancelBtn, &QPushButton::clicked, this, &KSaneWidget::cancelScan);
 
     d->m_activityFrame = new QWidget;
     QHBoxLayout *progress_lay = new QHBoxLayout(d->m_activityFrame);
@@ -229,7 +226,7 @@ QString KSaneWidget::vendor() const
     if (!vendor.isEmpty()) {
         return vendor;
     }
-    
+
     const QString &name = d->m_ksaneCoreInterface->deviceName();
     if (name.isEmpty()) {
         return QString();
@@ -251,7 +248,7 @@ QString KSaneWidget::model() const
     if (!model.isEmpty()) {
         return model;
     }
-    
+
     const QString &name = d->m_ksaneCoreInterface->deviceName();
     if (name.isEmpty()) {
         return QString();
@@ -266,9 +263,9 @@ QString KSaneWidget::selectDevice(QWidget *parent)
 {
     QString selected_name;
     QPointer<KSaneDeviceDialog> sel = new KSaneDeviceDialog(parent);
-    connect(d->m_ksaneCoreInterface, &KSaneCore::availableDevices, sel, &KSaneDeviceDialog::updateDevicesList);
-    connect(sel, &KSaneDeviceDialog::requestReloadList, d->m_ksaneCoreInterface, &KSaneCore::reloadDevicesList);
-    
+    connect(d->m_ksaneCoreInterface, &KSaneCore::Interface::availableDevices, sel, &KSaneDeviceDialog::updateDevicesList);
+    connect(sel, &KSaneDeviceDialog::requestReloadList, d->m_ksaneCoreInterface, &KSaneCore::Interface::reloadDevicesList);
+
     d->m_ksaneCoreInterface->reloadDevicesList();
 
     if (sel->exec() == QDialog::Accepted) {
@@ -293,15 +290,15 @@ bool KSaneWidget::openDevice(const QString &deviceName)
     QString                        myFolderName = QStringLiteral("ksane");
     QMap<QString, QString>         wallet_entry;
 
-    KSaneCore::KSaneOpenStatus status = d->m_ksaneCoreInterface->openDevice(deviceName);
-    if (status == KSaneCore::OpeningFailed) {
+    KSaneCore::Interface::OpenStatus status = d->m_ksaneCoreInterface->openDevice(deviceName);
+    if (status == KSaneCore::Interface::OpeningFailed) {
         return false;
     }
 
     bool password_dialog_ok = true;
 
     // prepare wallet for authentication and create password dialog
-    if (status == KSaneCore::OpeningDenied) {
+    if (status == KSaneCore::Interface::OpeningDenied) {
 #ifdef HAVE_KF5WALLET
         saneWallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), winId());
 
@@ -328,20 +325,20 @@ bool KSaneWidget::openDevice(const QString &deviceName)
 
     // sane_open failed due to insufficient authorization
     // retry opening device with user provided data assisted with kwallet records
-    while (status == KSaneCore::OpeningDenied) {
+    while (status == KSaneCore::Interface::OpeningDenied) {
 
         password_dialog_ok = dlg->exec();
         if (!password_dialog_ok) {
             delete dlg;
             return false; //the user canceled
         }
-        
+
         // add/update the device user-name and password for authentication
         status = d->m_ksaneCoreInterface->openRestrictedDevice(deviceName, dlg->username(), dlg->password());
 
 #ifdef HAVE_KF5WALLET
         // store password in wallet on successful authentication
-        if (dlg->keepPassword() && status != KSaneCore::OpeningDenied) {
+        if (dlg->keepPassword() && status != KSaneCore::Interface::OpeningDenied) {
             QMap<QString, QString> entry;
             entry[QStringLiteral("username")] = dlg->username();
             entry[QStringLiteral("password")] = dlg->password();
@@ -484,13 +481,13 @@ QImage KSaneWidget::toQImage(const QByteArray &data,
 {
 
     if ((format == FormatRGB_16_C) || (format == FormatGrayScale16)) {
-        d->alertUser(KSaneCore::ErrorGeneral, i18n("The image data contained 16 bits per color, "
+        d->alertUser(KSaneCore::Interface::ErrorGeneral, i18n("The image data contained 16 bits per color, "
                      "but the color depth has been truncated to 8 bits per color."));
     }
     return toQImageSilent(data, width, height, bytes_per_line, format);
 }
 
-void KSaneWidget::scanFinal()
+void KSaneWidget::startScan()
 {
     if (d->m_btnFrame->isEnabled()) {
         d->m_cancelMultiScan = false;
@@ -501,6 +498,11 @@ void KSaneWidget::scanFinal()
     }
 }
 
+void KSaneWidget::scanFinal()
+{
+    startScan();
+}
+
 void KSaneWidget::startPreviewScan()
 {
     if (d->m_btnFrame->isEnabled()) {
@@ -512,43 +514,58 @@ void KSaneWidget::startPreviewScan()
     }
 }
 
-void KSaneWidget::scanCancel()
+void KSaneWidget::cancelScan()
 {
     d->m_cancelMultiScan = true;
     d->m_ksaneCoreInterface->stopScan();
 }
 
+void KSaneWidget::scanCancel()
+{
+    cancelScan();
+}
+
 void KSaneWidget::setPreviewResolution(float dpi)
 {
     d->m_previewDPI = dpi;
 }
 
-void KSaneWidget::getOptVals(QMap <QString, QString> &opts)
+void KSaneWidget::getOptionValues(QMap <QString, QString> &opts)
 {
     opts.clear();
     opts = d->m_ksaneCoreInterface->getOptionsMap();
 }
 
-bool KSaneWidget::getOptVal(const QString &optname, QString &value)
+void KSaneWidget::getOptVals(QMap <QString, QString> &opts)
+{
+    getOptionValues(opts);
+}
+
+bool KSaneWidget::getOptionValue(const QString &option, QString &value)
 {
     const auto optionsMap = d->m_ksaneCoreInterface->getOptionsMap();
     auto it = optionsMap.constBegin();
     while (it != optionsMap.constEnd()) {
-        if(it.key() == optname) {
+        if(it.key() == option) {
             value = it.value();
             return !value.isEmpty();
         }
-        it++;        
+        it++;
     }
     return false;
 }
 
-int KSaneWidget::setOptVals(const QMap <QString, QString> &opts)
+bool KSaneWidget::getOptVal(const QString &optname, QString &value)
+{
+    return getOptionValue(optname, value);
+}
+
+int KSaneWidget::setOptionValues(const QMap <QString, QString> &options)
 {
     int ret = 0;
 
-    ret = d->m_ksaneCoreInterface->setOptionsMap(opts);
-    
+    ret = d->m_ksaneCoreInterface->setOptionsMap(options);
+
     if ((d->m_splitGamChB) &&
             (d->m_optGamR) &&
             (d->m_optGamG) &&
@@ -570,7 +587,12 @@ int KSaneWidget::setOptVals(const QMap <QString, QString> &opts)
     return ret;
 }
 
-bool KSaneWidget::setOptVal(const QString &option, const QString &value)
+int KSaneWidget::setOptVals(const QMap <QString, QString> &opts)
+{
+    return setOptionValues(opts);
+}
+
+bool KSaneWidget::setOptionValue(const QString &option, const QString &value)
 {
     if (d->m_scanOngoing) {
         return false;
@@ -607,6 +629,11 @@ bool KSaneWidget::setOptVal(const QString &option, const QString &value)
     return false;
 }
 
+bool KSaneWidget::setOptVal(const QString &option, const QString &value)
+{
+    return setOptionValue(option, value);
+}
+
 void KSaneWidget::setScanButtonText(const QString &scanLabel)
 {
     if (d->m_scanBtn == nullptr) {
@@ -645,15 +672,18 @@ float KSaneWidget::scanAreaWidth()
 {
     float result = 0.0;
     if (d->m_optBrX) {
-        if (d->m_optBrX->valueUnit() == KSaneOption::UnitPixel) {
+        if (d->m_optBrX->valueUnit() == KSaneCore::Option::UnitPixel) {
             result = d->m_optBrX->maximumValue().toFloat();
-            float dpi = currentDPI();
+            float dpi = 0;
+            if (d->m_optRes) {
+                dpi = d->m_optRes->value().toFloat();
+            }
             if (dpi < 1) {
                 qCDebug(KSANE_LOG) << "Broken DPI value";
                 dpi = 1.0;
             }
             result = result / dpi / 25.4;
-        } else if (d->m_optBrX->valueUnit() == KSaneOption::UnitMilliMeter) {
+        } else if (d->m_optBrX->valueUnit() == KSaneCore::Option::UnitMilliMeter) {
             result = d->m_optBrX->maximumValue().toFloat();
         }
     }
@@ -664,15 +694,18 @@ float KSaneWidget::scanAreaHeight()
 {
     float result = 0.0;
     if (d->m_optBrY) {
-        if (d->m_optBrY->valueUnit() == KSaneOption::UnitPixel) {
+        if (d->m_optBrY->valueUnit() == KSaneCore::Option::UnitPixel) {
             result = d->m_optBrY->maximumValue().toFloat();
-            float dpi = currentDPI();
+            float dpi = 0;
+            if (d->m_optRes) {
+                dpi = d->m_optRes->value().toFloat();
+            }
             if (dpi < 1) {
                 qCDebug(KSANE_LOG) << "Broken DPI value";
                 dpi = 1.0;
             }
             result = result / dpi / 25.4;
-        } else if (d->m_optBrY->valueUnit() == KSaneOption::UnitMilliMeter) {
+        } else if (d->m_optBrY->valueUnit() == KSaneCore::Option::UnitMilliMeter) {
             result = d->m_optBrY->maximumValue().toFloat();
         }
     }
